# Functions

Daft Functions provide a set of built-in operations that can be applied to DataFrame columns. This page provides an overview of all the functions provided by Daft. Learn more about [column functions](../core_concepts.md#cross-column-aggregations) in Daft User Guide.

::: daft.functions
    options:
        filters: ["!^_"]
